module Core.Configuration where

import qualified Data.ByteString               as B

import           Core.Types
import           Crypto.Saltine.Core.SecretBox (newKey)
import           Crypto.Saltine.Class          (encode)
import           Configuration.Dotenv
import           System.Directory              (doesFileExist)
import           System.Environment            (getEnv)

main :: IO ()
main = do
  loadFile defaultConfig

keyFileInit :: IO ()
keyFileInit = do
  keyExists <- doesFileExist "./data/encryptionKey"
  case keyExists of
    True -> putStrLn "Using existing key"
    False -> do
      key <- newKey
      B.writeFile "./data/encryptionKey" (encode key)
      putStrLn "Creating new encryption key; any pre-existing DB entries will not decrypt"

dbPath :: IO String
dbPath = getEnv "dbFile"

confLinkLength :: IO String
confLinkLength = getEnv "linkLength"

adminEmail :: IO String
adminEmail = getEnv "adminEmail"

appPort :: IO String
appPort = getEnv "applicationPort"
